pub struct GatewayClientModule {
pub notifier: ModuleNotifier<GatewayClientStateMachines>,
pub redeem_key: Keypair,
pub lightning_manager: Arc<dyn IGatewayClientV1>,
/* private fields */
}Expand description
Client side Lightning module for the gateway.
For the client side Lightning module for normal clients,
see fedimint_ln_client::LightningClientModule
Fields
notifier: ModuleNotifier<GatewayClientStateMachines>redeem_key: Keypairlightning_manager: Arc<dyn IGatewayClientV1>Implementations
Sourceimpl GatewayClientModule
impl GatewayClientModule
Sourcepub async fn try_register_with_federation(
&self,
route_hints: Vec<RouteHint>,
time_to_live: Duration,
fees: RoutingFees,
lightning_context: LightningContext,
api: SafeUrl,
gateway_id: PublicKey,
)
pub async fn try_register_with_federation( &self, route_hints: Vec<RouteHint>, time_to_live: Duration, fees: RoutingFees, lightning_context: LightningContext, api: SafeUrl, gateway_id: PublicKey, )
Register gateway with federation
Sourcepub async fn remove_from_federation(&self, gateway_keypair: Keypair)
pub async fn remove_from_federation(&self, gateway_keypair: Keypair)
Attempts to remove a gateway’s registration from the federation. Since removing gateway registrations is best effort, this does not return an error and simply emits a warning when the registration cannot be removed.
Sourcepub async fn gateway_handle_intercepted_htlc(
&self,
htlc: Htlc,
) -> Result<OperationId>
pub async fn gateway_handle_intercepted_htlc( &self, htlc: Htlc, ) -> Result<OperationId>
Attempt fulfill HTLC by buying preimage from the federation
Sourcepub async fn gateway_handle_direct_swap(
&self,
swap_params: SwapParameters,
) -> Result<OperationId>
pub async fn gateway_handle_direct_swap( &self, swap_params: SwapParameters, ) -> Result<OperationId>
Attempt buying preimage from this federation in order to fulfill a pay request in another federation served by this gateway. In direct swap scenario, the gateway DOES NOT send payment over the lightning network
Sourcepub async fn gateway_subscribe_ln_receive(
&self,
operation_id: OperationId,
) -> Result<UpdateStreamOrOutcome<GatewayExtReceiveStates>>
pub async fn gateway_subscribe_ln_receive( &self, operation_id: OperationId, ) -> Result<UpdateStreamOrOutcome<GatewayExtReceiveStates>>
Subscribe to updates when the gateway is handling an intercepted HTLC, or direct swap between federations
Sourcepub async fn await_completion(&self, operation_id: OperationId)
pub async fn await_completion(&self, operation_id: OperationId)
For the given OperationId, this function will wait until the Complete
state machine has finished or failed.
Sourcepub async fn gateway_pay_bolt11_invoice(
&self,
pay_invoice_payload: PayInvoicePayload,
) -> Result<OperationId>
pub async fn gateway_pay_bolt11_invoice( &self, pay_invoice_payload: PayInvoicePayload, ) -> Result<OperationId>
Pay lightning invoice on behalf of federation user
pub async fn gateway_subscribe_ln_pay( &self, operation_id: OperationId, ) -> Result<UpdateStreamOrOutcome<GatewayExtPayStates>>